==> libplasma-5.91.0.tar.xz: libplasma-5.91.0/src/desktoptheme/breeze-light/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[de]": "KDE Visual Design Group",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队"
            }
        ],
        "Category": "",
        "Description": "Breeze Light by the KDE VDG",
        "Description[ar]": "نسيم فاتح من مجموعة تصميم كِيدِي",
        "Description[az]": "Breeze -İşıqlı - KDE VDG tərəfindən",
        "Description[be]": "Breeze Light ад KDE VDG",
        "Description[bg]": "Breeze Светъл от KDE VDG",
        "Description[ca@valencia]": "Brisa clara, creat pel VDG de KDE",
        "Description[ca]": "Brisa clara, creat pel VDG del KDE",
        "Description[cs]": "Breeze Light od KDE VDG",
        "Description[de]": "Breeze Hell von der KDE VDG",
        "Description[en_GB]": "Breeze Light by the KDE VDG",
        "Description[eo]": "Breeze Light de la KDE VDG",
        "Description[es]": "Brisa claro por KDE VDG",
        "Description[eu]": "Brisa argia, KDE VDGk egina",
        "Description[fi]": "Vaalea Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze clair par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa clara do KDE VDG.",
        "Description[he]": "בריזה בהירה מאת קבוצת העיצוב החזותי של KDE",
        "Description[ia]": "Brisa Ligier per KDE VDG",
        "Description[id]": "Breeze Terang oleh KDE VDG",
        "Description[it]": "Brezza chiaro a cura del VDG di KDE",
        "Description[ka]": "Breeze-ის ღია ვარიანტი, KDE VDG-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 밝은 Breeze",
        "Description[nl]": "Breeze Light door de KDE VDG",
        "Description[nn]": "Breeze skumring frå KDE VDG",
        "Description[pl]": "Jasna Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa Claro da VDG do KDE",
        "Description[pt_BR]": "Breeze Light pelo KDE VDG",
        "Description[ru]": "Светлый вариант Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze Light",
        "Description[sk]": "Vánok Svetlý od KDE VDG",
        "Description[sl]": "Svetla sapica od KDE VDG",
        "Description[sv]": "Breeze ljus av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் வெளிர் பிரீஸ்",
        "Description[tr]": "KDE VDG tarafından Esinti Açık",
        "Description[uk]": "Світла Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze Sáng, do KDE VDG",
        "Description[x-test]": "xxBreeze Light by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风浅色主题，由 KDE VDG (视觉设计团队) 设计制作",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze Light",
        "Name[ar]": "نسيم فاتح",
        "Name[az]": "Breeze - İşıqlı",
        "Name[be]": "Breeze Light",
        "Name[bg]": "Breeze Светъл",
        "Name[ca@valencia]": "Brisa clara",
        "Name[ca]": "Brisa clara",
        "Name[cs]": "Breeze Světlé",
        "Name[de]": "Breeze Hell",
        "Name[en_GB]": "Breeze Light",
        "Name[eo]": "Briza Lumo",
        "Name[es]": "Brisa claro",
        "Name[eu]": "Brisa argia",
        "Name[fi]": "Vaalea Breeze",
        "Name[fr]": "Breeze clair",
        "Name[gl]": "Brisa clara",
        "Name[he]": "בריזה בהירה",
        "Name[ia]": "Brisa Ligier",
        "Name[id]": "Breeze Terang",
        "Name[it]": "Brezza chiaro",
        "Name[ka]": "ნიავი ღია",
        "Name[ko]": "밝은 Breeze",
        "Name[nl]": "Breeze Light",
        "Name[nn]": "Breeze lys",
        "Name[pl]": "Jasna Bryza",
        "Name[pt]": "Brisa Clara",
        "Name[pt_BR]": "Breeze Light",
        "Name[ru]": "Breeze, светлый вариант",
        "Name[sa]": "Breeze Light",
        "Name[sk]": "Vánok Svetlý",
        "Name[sl]": "Svetla sapica",
        "Name[sv]": "Breeze ljus",
        "Name[ta]": "வெளிர் பிரீஸ்",
        "Name[tr]": "Esinti Açık",
        "Name[uk]": "Світла Breeze",
        "Name[vi]": "Breeze Sáng",
        "Name[x-test]": "xxBreeze Lightxx",
        "Name[zh_CN]": "Breeze 微风浅色",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> libplasma-5.92.0.tar.xz: libplasma-5.92.0/src/desktoptheme/breeze-light/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[de]": "KDE Visual Design Group",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[hu]": "KDE Visual Design Group",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队",
                "Name[zh_TW]": "KDE VDG 視覺設計組"
            }
        ],
        "Category": "",
        "Description": "Breeze Light by the KDE VDG",
        "Description[ar]": "نسيم فاتح من مجموعة تصميم كِيدِي",
        "Description[az]": "Breeze -İşıqlı - KDE VDG tərəfindən",
        "Description[be]": "Breeze Light ад KDE VDG",
        "Description[bg]": "Breeze Светъл от KDE VDG",
        "Description[ca@valencia]": "Brisa clara, creat pel VDG de KDE",
        "Description[ca]": "Brisa clara, creat pel VDG del KDE",
        "Description[cs]": "Breeze Light od KDE VDG",
        "Description[de]": "Breeze Hell von der KDE VDG",
        "Description[en_GB]": "Breeze Light by the KDE VDG",
        "Description[eo]": "Breeze Light de la KDE VDG",
        "Description[es]": "Brisa claro por KDE VDG",
        "Description[eu]": "Brisa argia, KDE VDGk egina",
        "Description[fi]": "Vaalea Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze clair par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa clara do KDE VDG.",
        "Description[he]": "בריזה בהירה מאת קבוצת העיצוב החזותי של KDE",
        "Description[hu]": "Breeze Light a KDE VDG-től",
        "Description[ia]": "Brisa Ligier per KDE VDG",
        "Description[id]": "Breeze Terang oleh KDE VDG",
        "Description[it]": "Brezza chiaro a cura del VDG di KDE",
        "Description[ka]": "Breeze-ის ღია ვარიანტი, KDE VDG-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 밝은 Breeze",
        "Description[nl]": "Breeze Light door de KDE VDG",
        "Description[nn]": "Breeze skumring frå KDE VDG",
        "Description[pl]": "Jasna Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa Claro da VDG do KDE",
        "Description[pt_BR]": "Breeze Light pelo KDE VDG",
        "Description[ru]": "Светлый вариант Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze Light",
        "Description[sk]": "Vánok Svetlý od KDE VDG",
        "Description[sl]": "Svetla sapica od KDE VDG",
        "Description[sv]": "Breeze ljus av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் வெளிர் பிரீஸ்",
        "Description[tr]": "KDE VDG tarafından Esinti Açık",
        "Description[uk]": "Світла Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze Sáng, do KDE VDG",
        "Description[x-test]": "xxBreeze Light by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风浅色主题，由 KDE VDG (视觉设计团队) 设计制作",
        "Description[zh_TW]": "由 KDE VDG 製作的 Breeze Light",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze Light",
        "Name[ar]": "نسيم فاتح",
        "Name[az]": "Breeze - İşıqlı",
        "Name[be]": "Breeze Light",
        "Name[bg]": "Breeze Светъл",
        "Name[ca@valencia]": "Brisa clara",
        "Name[ca]": "Brisa clara",
        "Name[cs]": "Breeze Světlé",
        "Name[de]": "Breeze Hell",
        "Name[en_GB]": "Breeze Light",
        "Name[eo]": "Briza Lumo",
        "Name[es]": "Brisa claro",
        "Name[eu]": "Brisa argia",
        "Name[fi]": "Vaalea Breeze",
        "Name[fr]": "Breeze clair",
        "Name[gl]": "Brisa clara",
        "Name[he]": "בריזה בהירה",
        "Name[hu]": "Breeze Light",
        "Name[ia]": "Brisa Ligier",
        "Name[id]": "Breeze Terang",
        "Name[it]": "Brezza chiaro",
        "Name[ka]": "ნიავი ღია",
        "Name[ko]": "밝은 Breeze",
        "Name[nl]": "Breeze Light",
        "Name[nn]": "Breeze lys",
        "Name[pl]": "Jasna Bryza",
        "Name[pt]": "Brisa Clara",
        "Name[pt_BR]": "Breeze Light",
        "Name[ru]": "Breeze, светлый вариант",
        "Name[sa]": "Breeze Light",
        "Name[sk]": "Vánok Svetlý",
        "Name[sl]": "Svetla sapica",
        "Name[sv]": "Breeze ljus",
        "Name[ta]": "வெளிர் பிரீஸ்",
        "Name[tr]": "Esinti Açık",
        "Name[uk]": "Світла Breeze",
        "Name[vi]": "Breeze Sáng",
        "Name[x-test]": "xxBreeze Lightxx",
        "Name[zh_CN]": "Breeze 微风浅色",
        "Name[zh_TW]": "Breeze Light",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
